==> tecfy_core_package-1.0.58.tar.gz: lib/models/entity/property_many_to_many.model.dart <==
part of tecfy_core_client_package;

class PropertyManyToMany extends Property {
  late String middleEntityName;
  late String middlePropertyName;
  late String middleOtherPropertyName;
  late bool useArrayStringValue;
  late String entityName;

  /// <summary>
  /// When value is true, the type should be List<ManyToManyTableName>
  /// but when it's false the type should be List<int>
  /// </summary>
  late bool isWithData;

  late bool isFilter;

  /// <summary>
  /// where value of FilterField is null of embty then the value of FilterValueField must refer to Array proerty of same dropdwn Entity
  /// </summary>
  String? filterField;

  /// <summary>
  /// where value of FilterField is null of embty then the value of FilterValueField must refer to Array proerty of same dropdwn Entity
  /// </summary>
  String? filterValueField;

  PropertyManyToMany.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    middleEntityName = lowerFirst(row['middleEntityName']) ?? '';
    middlePropertyName = lowerFirst(row['middlePropertyName']) ?? '';
    middleOtherPropertyName = lowerFirst(row['middleOtherPropertyName']) ?? '';
    entityName = lowerFirst(row['entityName']) ?? '';
    isWithData = row['isWithData'];

    useArrayStringValue = row['useArrayStringValue'];
    isFilter = row['isFilter'];
    filterField = lowerFirst(row['filterField']);
    filterValueField = lowerFirst(row['filterValueField']);
  }
  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text('ManyToMany');
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    return 'ManyToMany';
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null) return false;

    return false;
  }
}

==> tecfy_core_package-1.1.42.tar.gz: lib/models/entity/property_many_to_many.model.dart <==
part of tecfy_core_client_package;

class PropertyManyToMany extends Property {
  late String middleEntityName;
  late String middlePropertyName;
  late String middleOtherPropertyName;
  late bool useArrayStringValue;
  late String entityName;

  /// <summary>
  /// When value is true, the type should be List<ManyToManyTableName>
  /// but when it's false the type should be List<int>
  /// </summary>
  late bool isWithData;

  late bool isFilter;

  /// <summary>
  /// where value of FilterField is null of embty then the value of FilterValueField must refer to Array proerty of same dropdwn Entity
  /// </summary>
  String? filterField;

  /// <summary>
  /// where value of FilterField is null of embty then the value of FilterValueField must refer to Array proerty of same dropdwn Entity
  /// </summary>
  String filterValueField = '';

  List<Map<String, String>>? options;

  PropertyManyToMany.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    middleEntityName = lowerFirst(row['middleEntityName']) ?? '';
    middlePropertyName = lowerFirst(row['middlePropertyName']) ?? '';
    middleOtherPropertyName = lowerFirst(row['middleOtherPropertyName']) ?? '';
    entityName = lowerFirst(row['entityName']) ?? '';
    isWithData = row['isWithData'];

    useArrayStringValue = row['useArrayStringValue'];
    isFilter = row['isFilter'];
    filterField = lowerFirst(row['filterField']);
    filterValueField = lowerFirst(row['filterValueField'] ?? '') ?? '';
    if (entityName.isEmpty && filterValueField.isNotEmpty) {
      filterValueField = row['filterValueField'];
    }
    bindOptions();
  }

  void bindOptions() {
    if (entityName.isEmpty && filterValueField.isNotEmpty) {
      options = filterValueField.split(',').map<Map<String, String>>((e) {
        var s = e.split(':');
        return {
          'id': s.first,
          'nameEn': s.first,
          'nameAr': s.last,
        };
      }).toList();
    }
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text('ManyToMany');
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    return 'ManyToMany';
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null) return false;

    return false;
  }
}
